import { CoreAdmin, CoreLayoutProps } from '@rakit/core';
import { FetchContextProvider, useFetch } from '@rakit/fetch';
import { Error, Loading, ThemeProvider } from '@rakit/joy-ui';
import { createAuthProvider } from './config/createAuthProvider';
import { createDataProvider } from './config/createDataProvider';
import { i18nProvider } from './config/i18nProvider';
import { lazy, Suspense } from 'react';
import { Route } from 'react-router-dom';

const AppLoading = () => <Loading />

const Layout = (props: CoreLayoutProps) => {
  return (
    <Suspense fallback={<Loading />}>
      {props.children}
    </Suspense>
  )
}

const CatchAll = lazy(() => import("./pages/CatchAll"));
const SignIn = lazy(() => import("./pages/SignIn"));
const PageError = lazy(() => import("./pages/PageError"));

export default function App() {
  return (
    <FetchContextProvider>
      <ThemeProvider>
        <AppContext />
      </ThemeProvider>
    </FetchContextProvider>
  );
}

function AppContext() {
  const fetch = useFetch();

  const authProvider = createAuthProvider(fetch);
  const dataProvider = createDataProvider(fetch);

  return (
    <CoreAdmin
      authProvider={authProvider}
      // authCallbackPage={ }
      // basename={ }
      catchAll={<CatchAll />}
      dataProvider={dataProvider}
      error={Error}
      dashboard={<CatchAll />}
      initialLocation="/"
      i18nProvider={i18nProvider}
      loading={AppLoading}
      layout={Layout}
      loginPage={SignIn}
      // ready={ }
      requireAuth={false}
      // store={ }
      title="进销存系统"
    >
      <Route
        path="/error/:status"
        element={<PageError />}
      />
      <Route
        path="/sasda"
        element={<div>哈哈哈哈</div>}
      />
      <Route
        path="/sasda2"
        element={<div>哈哈222哈哈</div>}
      />
    </CoreAdmin>
  )
}
